#!/bin/bash

# PSXC IMDB INFO #
##################

# This is the first beta-release of the new imdb script. A lot has changed, but most should be
# familiar if you've used the script previously. One of the new things are a separate config-file.
# Just edit the 2 lines below, then continue on the "real" config file.

# version number. do not change.
VERSION="v2.0a"

# your glftpd root path.
GLROOT=/glftpd

# path to the config file when chrooted by glftpd.
CONFFILE=/etc/psxc-imdb.conf

## End of config ##
###################

######################################################################################################

# check if configfile exists
############################

if [ -r $GLROOT$CONFFILE ]; then
 . $GLROOT$CONFFILE
 if [ $? -ne 0 ]; then
  echo "Unable to open config file ($GLROOT$CONFFILE). Forced to exit."
  exit 0
 fi
elif [ -r $CONFFILE ]; then
 . $CONFFILE
 if [ $? -ne 0 ]; then
  echo "Unable to open config file ($CONFFILE). Forced to exit."
  exit 0
 fi
else
 echo "Config file not found. Forced to exit."
 exit 0
fi

if [ ! -z "$@" ]; then

# This is what is run under zs-c, chrooted.
###########################################

 PATH=$PATHCHROOTED
 IMDBLOG=$IMDBLOGCHROOTED
 FILENAME="$@"
 case $FILENAME in
  *.[nN][fF][oO])
   if [ ! -z "$DOTDATE" ]; then
    grep [Dd][Aa][Tt][Ee] $FILENAME | tr -c '/a-zA-Z0-9:. -/\n' ' ' | tr -s ' ' > $DOTDATE
    chmod 644 $DOTDATE
   fi
   IMDBURL="`grep [Ii][Mm][Dd][Bb] $FILENAME | tr ' ' '\n' | sed -n /[hH][tT][tT][pP]:[/][/].*[.][iI][mM][dD][bB].*[?].[0-9]/p | head -n 1 | tr -c 'a-zA-Z0-9:./?' ' ' | sed "s/ //g"`"
   if [ ! -z "`echo $IMDBURL | grep "\.imdb\."`" ]; then
    IMDBURL="http://us.imdb.com/Title?""`echo $IMDBURL | sed "s/=/-/g" | sed "s/.imdb./=/" | cut -d "=" -f 2 | cut -d "?" -f 2 | cut -b 1-7 | tr -c '0-9' ' ' | sed "s/ //g"`"
   fi
   if [ ! -z "$IMDBURL" ]; then
    echo "$IMDBURL""|""$PWD" >> $IMDBLOG
    if [ ! -z "$DOTIMDB" ]; then
     echo -n "" > $DOTIMDB
     chmod 666 $DOTIMDB
    fi
    if [ ! -z "$DOTURL" ]; then
     DOTIMDB="`basename "$PWD" | sed "s/ /./g"`.url"
     echo "[InternetShortcut]" > $DOTIMDB
     echo "URL=""$IMDBURL" > $DOTIMDB
     chmod 644 $DOTIMDB
    fi
   fi
  ;;
 esac
 exit 0

else
 if [ "`basename $0`" = "$PRENAME" ]; then

# This is what is done with pre's
#################################

  PATH=$GLPATHPRE
  a="`tail -n 5 $GLPRELOG | grep "$PRETRIGGER" | tail -n 1`"
  DIRNAME=""
  for WORD in $WORDS; do
   count=0
   combine=0
   if [ -z "$a" ]; then
    exit 0
   fi
   if [ ! -z "$PRETRIGGER" ]; then
    let WORD=WORD+1
   fi
   for b in $a; do
    if [ -z `echo $b | grep "$PRETRIGGER"` ] && [ $count -gt 0 ] || [ -z "$PRETRIGGER" ]; then
     if [ $combine -eq 1 ]; then
      c=$c$b
     else
      c=$b
     fi
     if [ ! -z `echo "$c" | grep "^\""` ]; then
      combine=1
     else
      c=$b
      let count=count+1
     fi
     if [ ! -z `echo "$c" | grep "\"$"` ]; then
      combine=0
      let count=count+1
     fi
     if [ $count -eq $WORD ]; then
      break
     fi
    else
     if [ "$b" = "$PRETRIGGER" ]; then
      count=1
     fi
    fi
   done
   DIRNAME="$DIRNAME""$c"
  done
  DIRNAME=`echo $DIRNAME | sed "s|\"\"|$SEPARATOR|g" | sed "s|\"||g"`
  if [ -d $GLROOT$DIRNAME ]; then
   FILENAME=`ls -1 $GLROOT$DIRNAME | grep "\.[Nn][Ff][Oo]$" | head -1`
   IMDBURL="`grep [Ii][Mm][Dd][Bb] $GLPREROOT$DIRNAME/$FILENAME | tr ' ' '\n' | sed -n /[hH][tT][tT][pP]:[/][/].*[.][iI][mM][dD][bB].*[?].[0-9]/p | head -n 1 | tr -c 'a-zA-Z0-9:./?' ' ' | sed "s/ //g"`"
   if [ ! -z "`echo $IMDBURL | grep "\.imdb\."`" ]; then
    IMDBURL="http://us.imdb.com/Title?""`echo $IMDBURL | sed "s/=/-/g" | sed "s/.imdb./=/" | cut -d "=" -f 2 | cut -d "?" -f 2 | cut -b 1-7 | tr -c '0-9' ' ' | sed "s/ //g"`"
   fi
   if [ ! -z "$IMDBURL" ]; then
    echo "$IMDBURL""|""$DIRNAME" >> $IMDBLOG
   fi
  fi
  exit 0
 fi

 if [ ! -e $IMDBLOG ]; then

# Check to see if it's a first-run
##################################

  echo "Seems like this is the first time the script is run."
  echo "I will try to check/setup everything."
  echo "You are running this script as `whoami`. Please use"
  echo "the same user's crontab when/if setting this up."
  echo ""
  echo "testing if all needed binaries are present..."
  BINARIES="date cat echo cut lynx grep head sed awk fold rm bash ls basename dirname chmod"
  BINARIESCHROOT="grep tr sed head echo bash chmod basename"
  echo -n "In $GLROOT/bin: "
  for BINAR in $BINARIESCHROOT; do
   test -e $GLROOT/bin/$BINAR || { echo "$BINAR missing. Please fix."; exit 1; };
   echo -n "."
  done
  echo ""
  echo -n "In $PATH: "
  for BINAR in $BINARIES; do
   which $BINAR >/dev/null 2>&1 || { echo "$BINAR missing/not in path. Please fix."; exit 1; };
   echo -n "."
  done
  echo ""
  echo "Initializing the files..."
  test -w $GLLOG || { echo "`whoami` Can not write to \$GLLOG ($GLLOG)"; exit 1; };
  touch $TMPFILE >/dev/null 2>&1 || { echo "ERROR! Could not create \$TMPFILE ($TMPFILE)"; exit 1; };
  chmod 666 $TMPFILE || { echo "could not make $TMPFILE world writable."; exit 1; };
  touch $IMDBURLLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBURLLOG ($IMDBURLLOG)"; exit 1; };
  chmod 666 $IMDBURLLOG || { echo "could not make $IMDBURLLOG world writable."; exit 1; };
  touch $IMDBLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBLOG ($IMDBLOG)"; exit 1; };
  chmod 666 $IMDBLOG || { echo "could not make $IMDBLOG world writable."; exit 1; };
  touch $IMDBPID >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBPID ($IMDBPID)"; exit 1; };
  chmod 666 $IMDBPID || { echo "could not make $IMDBPID world writable."; exit 1; };
  echo "Done testing. Everything seems to be okay."
  exit 0
 fi

# The main part.
################

 if [ -z "`cat $IMDBLOG`" ]; then

# No new imdb-info. let's quit.
###############################
  exit 0
 fi

 if [ ! -z "`cat $IMDBPID`" ]; then

# Another instance of this script is running. Quit.
  exit 0
 fi

# Seems like something was put into the log. Let's check it.
############################################################
 echo $$ > $IMDBPID
 BOTHEADORIG="$BOTHEAD"
 DOTIMDBORIG="$DOTIMDB"
 USEBOTORIG="$USEBOT"
 LYNXTRIESORIG="$LYNXTRIES"
 USEBUSINESSORIG="$USEBUSINESS"
 USEPREMIEREORIG="$USEPREMIERE"
 USELIMITEDORIG="$USELIMITED"
 IMDBLINE=`head -n 1 $IMDBLOG`
 cat $IMDBLOG | grep -v "$IMDBLINE" > $TMPFILE
 cat $TMPFILE > $IMDBLOG
  BUSINESS=""
  BUSINESSSHORT=""
  PREMIERE=""
  LIMITED=""
  EXEMPTED=""
  BOTHEAD="$BOTHEADORIG"
  DOTIMDB="$DOTIMDBORIG"
  USEBOT="$USEBOTORIG"
  LYNXTRIES="$LYNXTRIESORIG"
  USEBUSINESS="$USEBUSINESSORIG"
  USEPREMIERE="$USEPREMIEREORIG"
  USELIMITED="$USELIMITEDORIG"
  IMDBURL="`echo $IMDBLINE | cut -d "|" -f 1`"
  IMDBLNK="`echo $IMDBLINE | cut -d "|" -f 2`"
  DEBUGCOUNT=1
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"
  fi
  if [ -d $GLROOT$IMDBLNK ]; then
   IMDBDIR="`basename $IMDBLNK`"
   BASELNK="`dirname $IMDBLNK`"
   IMDBLKL="$IMDBLNK"
   IMDBLNK="$GLROOT$IMDBLNK/$DOTIMDB"
  elif [ "$IMDBLNK" = "/dev/null" ]; then
   IMDBLKL="$IMDBLNK"
   DOTIMDB=""
  else
   DOTIMDB=""
   USEBOT=""
  fi
  DEBUGCOUNT=2
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  for EXEMPT in $BOTEXEMPT; do
   if [ ! -z `echo "$BASELNK" | grep "$EXEMPT"` ]; then
    USEBOT=""
    EXEMPTED="ON"
   fi
  done
  DEBUGCOUNT=3
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  if [ ! -z `cat $IMDBURLLOG | grep $IMDBURL` ] || [ ! -z $EXEMPTED ]; then
   USEBOT=""
  else
   echo $IMDBURL >> $IMDBURLLOG
   tail -n $KEEPURLS $IMDBURLLOG > $TMPFILE
   cat $TMPFILE > $IMDBURLLOG
   echo -n "" > $TMPFILE
  fi
  DEBUGCOUNT=4
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  while [ $LYNXTRIES -gt 0 ]; do
   lynx $LYNXFLAGS $IMDBURL > $TMPFILE 2>&1 | {
    if [ $? = "0" ]; then
     exit 0
    else
     exit 1
    fi
   }
   if [ $? = "1" ]; then
    let LYNXTRIES=LYNXTRIES-1
    sleep 1
   else
    LYNXTRIES="$LYNXTRIESORIG"
    break
   fi
  done
  if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then

# Check for a movie-title. This *must* be present, else the script will just exit.
##################################################################################
   TITLE=`cat $TMPFILE | grep "^[a-zA-Z0-9\"]" | sed "s/\"//g" | head -1`
   if [ -z "$TITLE" ]; then
    # a new version of lynx? let's try a diff. approach.
    TITLE=`cat $TMPFILE | grep "([0-9][0-9][0-9][0-9])" | head -1 | sed "s/PageFlicker//" | sed "s/\"//g"`
   fi
   if [ "$TITLE" = "IMDb title search" ] || [ -z "$TITLE" ]; then

# No title was found. make sure no garbage gets spilled to channel and file.
############################################################################
    USEBOT=""
    DOTIMDB=""
   else

# Grab hold of the info we'll use later. Also do some formatting.
#################################################################

    GENRE=`cat $TMPFILE | grep "Genre:" | sed "s/(more)//" | sed "s/   //" | sed "s/Genre:/Genre........:/" | sed s/\"/$QUOTECHAR/g | head -1`
    GENRECLEAN=`echo $GENRE | sed "s/Genre........: //"`
    RATING=`cat $TMPFILE | grep "User\ Rating:" | sed "s/   //" | sed "s/ [Vv][Oo][Tt][Ee] [Hh][Ee][Rr][Ee]//" | sed "s/User Rating:/User Rating..:/" | sed "s/* //g" | sed "s/_ //g" | sed s/\"/$QUOTECHAR/g | head -1`
    RATINGCLEAN=`echo $RATING | sed "s/User Rating..: //"`
    COUNTRY=`cat $TMPFILE | grep "Country:" | sed "s/   //" | sed "s/Country:/Country......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    COUNTRYCLEAN=`echo $COUNTRY | sed "s/Country......: //"`
    TAGLINE=`cat $TMPFILE | grep "Tagline:" | sed "s/(more)//" | sed "s/   //" | sed "s/([Mm][Oo][Rr][Ee])//" | sed "s/Tagline:/Tagline......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    TAGLINECLEAN=`echo $TAGLINE | sed "s/Tagline......: //"`
    LANGUAGE=`cat $TMPFILE | grep "Language:" | sed "s/   //" | sed "s/Language:/Language.....:/" | sed s/\"/$QUOTECHAR/g | head -1`
    LANGUAGECLEAN=`echo $LANGUAGE | sed "s/Language.....: //"`
    PLOT=`cat $TMPFILE | grep "Plot\ [OS][u][tm][lm][ia][nr][ey]:" | sed "s/   //" | sed "s/ ([Vv][Ii][Ee][Ww] [Tt][Rr][Aa][Ii][Ll][Ee][Rr])//" | sed "s/([Mm][Oo][Rr][Ee])//" | sed "s/Plot [OS][u][tm][lm][ia][nr][ey][:]/Plot Outline.:/" | sed s/\"/$QUOTECHAR/g | head -1`
    PLOTCLEAN=`echo $PLOT | sed "s/Plot Outline.: //"`
    CERT=`cat $TMPFILE | grep "Certification:" | sed "s/   //" | sed s/\"/$QUOTECHAR/g | head -1`
    CERTCLEAN=`echo $CERT | sed "s/Certification: //" | tr '/' '\n' | grep "[uU][sS][aA]" | tr -d ' '`
    CAST=`cat $TMPFILE | grep "\ \.\.\.\.\ " | sed s/\"/$QUOTECHAR/g | head -$CASTNUM`
    COMMENTSHORT=`cat $TMPFILE | grep "User Comments:" | head -1 | sed "s/   //" | sed "s/([Mm][Oo][Rr][Ee])//" | sed s/\"/$QUOTECHAR/g`
    COMMENT=`cat $TMPFILE | awk '/User Comments:$/, /Check for other user comments.$/' | sed s/\"/$QUOTECHAR/g`
    RUNTIME=`cat $TMPFILE | grep "Runtime:" |  sed "s/   //" | sed "s/Runtime:/Runtime......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    RUNTIMECLEAN=`echo $RUNTIME | sed "s/Runtime......: //"`
    DIRECTOR=`cat $TMPFILE | awk '/Directed by$/, /Writing credits$/' | grep -v "Directed by" | grep -v "Writing Credits" | sed "s/   //" | head -1 | sed s/\"/$QUOTECHAR/g`
    DIRECTORCLEAN=`echo $DIRECTOR`

    ONELINE="`echo "$BOLD$TITLE$BOLD""[$COUNTRY]: $GENRE - $BOLD$RATING$BOLD""- $IMDBURL" | sed "s/Genre........: //" | sed "s/User Rating..: //" | sed "s/Country......: //" | sed "s/  / /g"`"

    BUSINESSURL=`echo $IMDBURL | sed "s/Title/Business/"`
    RELEASEURL=`echo $IMDBURL | sed "s/Title/ReleaseDates/"`
    while [ $LYNXTRIES -gt 0 ]; do
     lynx -dump $IMDBURL > $TMPFILE 2>&1 | {
      if [ $? = "0" ]; then
       exit 0
      else
       exit 1
      fi
     }
     if [ $? = "1" ]; then
      let LYNXTRIES=LYNXTRIES-1
      sleep 1
     else
      LYNXTRIES="$LYNXTRIESORIG"
      break
     fi      
    done   
    if [ -z "`cat $TMPFILE | grep -F "$BUSINESSURL"`" ]; then
     USEBUSINESS=""
    fi
    if [ -z "`cat $TMPFILE | grep -F "$RELEASEURL"`" ]; then
     USEPREMIERE=""
     USELIMITED=""
    fi
    if [ ! -z "$USEBUSINESS" ]; then
     while [ $LYNXTRIES -gt 0 ]; do
      lynx $LYNXFLAGS $BUSINESSURL > $TMPFILE 2>&1 | {
       if [ $? = "0" ]; then
        exit 0
       else
        exit 1
       fi
      }
      if [ $? = "1" ]; then
       let LYNXTRIES=LYNXTRIES-1
       sleep 1
      else
       LYNXTRIES="$LYNXTRIESORIG"
       break
      fi
     done
     if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then
      BUSINESS=`cat $TMPFILE  | awk '/Opening Weekend$/,/Gross$/' | grep "(" | sed "s/       //" | sed s/\"/$QUOTECHAR/g`
      BUSINESSSHORT=`cat $TMPFILE | awk '/Opening Weekend$/,/Gross$/' | grep "[Ss][Cc][Rr][Ee][Ee][Nn][Ss]" | grep "USA" | sed "s/          //" | sed s/\"/$QUOTECHAR/g | head -1`
      if [ -z "$BUSINESSSHORT" ]; then
       BUSINESSSHORT=`cat $TMPFILE | awk '/Opening Weekend$/,/Gross$/' | grep "[Uu][Ss][Aa]" | sed "s/          //" | sed s/\"/$QUOTECHAR/g | head -1`
      fi
      if [ -z "$BUSINESSSHORT" ]; then
       BUSINESSSHORT=$BUSINESS
      fi
     fi
    fi
    if [ ! -z "$USEPREMIERE" ] || [ ! -z "$USELIMITED" ]; then
     while [ $LYNXTRIES -gt 0 ]; do
      lynx $LYNXFLAGS $RELEASEURL > $TMPFILE 2>&1 | {
       if [ $? = "0" ]; then
        exit 0
       else
        exit 1
       fi
      }
      if [ $? = "1" ]; then
       let LYNXTRIES=LYNXTRIES-1
       sleep 1
      else
       LYNXTRIES="$LYNXTRIESORIG"
       break
      fi
     done
     if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then
      if [ ! -z "$USEPREMIERE" ]; then
       PREMIERE=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep "(" | grep "[Pp][Rr][Ee][Mm][Ii][Ee][Rr][Ee]" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
       if [ -z "$PREMIERE" ]; then
        PREMIERE=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep -v "Date$" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
       fi
      fi
      if [ ! -z "$USELIMITED" ]; then
       LIMITED=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep "(" | grep "[Ll][Ii][Mm][Ii][Tt][Ee][Dd]" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
#       if [ "$PREMIERE" = "$LIMITED" ]; then
#        PREMIERE=""
#       fi
      fi
     fi
    fi
    if [ ! -z "$IMDBHEAD" ]; then
     BOTHEAD=`echo $BOTHEADORIG | sed s/RELEASENAME/$BOLD$IMDBDIR$BOLD/`
    fi
    if [ ! -z $DEBUG ]; then
     DEBUGCOUNT=5
     echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
     echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
    fi
    if [ ! -z "$DIRECTOR" ]; then
     DIRECTOR="Directed by..: $DIRECTOR"
    fi
   fi
   if [ ! -z $DEBUG ]; then
    DEBUGCOUNT=6
    echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
    echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
   fi

   if [ ! -z "$USEBOT" ]; then

# Time to put stuff out so the bot can read it.
###############################################

    HEADTMP="Title........: $BOLD$TITLE$BOLD"
    if [ ! -z "$COUNTRY" ]; then
     HEADTMP="$HEADTMP / $COUNTRY"
    fi
    if [ ! -z "$LANGUAGE" ]; then
     HEADTMP="$HEADTMP / $BOLD$LANGUAGE$BOLD"
    fi
    HEAD=`echo "$HEADTMP" | sed "s/Country......: //" | sed "s/Language.....: //"`
    if [ ! -z "$BOTHEAD" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$BOTHEAD\"" >> $GLLOG
    fi
    if [ ! -z "$HEAD" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$HEAD\"" >> $GLLOG
    fi
    if [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"IMDb Link....: $IMDBURL\"" >> $GLLOG
    fi
    if [ ! -z "$DIRECTOR" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$DIRECTOR\"" >> $GLLOG
    fi
    if [ ! -z "$GENRE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$GENRE\"" >> $GLLOG
    fi
    if [ ! -z "$RATING" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$RATING\"" >> $GLLOG
    fi
    if [ ! -z "$RUNTIME" ] && [ -z "$BOTONELINE" ]; then  
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$RUNTIME\"" >> $GLLOG
    fi
    if [ ! -z "$BUSINESSSHORT" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Opening Stats: $BUSINESSSHORT\"" >> $GLLOG
    fi
    if [ ! -z "$PREMIERE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Premiere Date: $PREMIERE\"" >> $GLLOG
    fi
    if [ ! -z "$LIMITED" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Limited Date.: $LIMITED\"" >> $GLLOG
    fi
    if [ ! -z "$TAGLINE" ] && [ ! -z "$PLOT" ] && [ -z "$BOTONELINE" ]; then
     if [ "$TAGPLOT" = "TAG" ]; then
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
     elif [ "$TAGPLOT" = "PLOT" ]; then
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
     fi
    elif [ -z "$TAGPLOT" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
    elif [ ! -z "$TAGLINE" ] && [ ! "$TAGPLOT" = "NONE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
    elif [ ! -z "$PLOT" ] && [ ! "$TAGPLOT" = "NONE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
    fi
    if [ ! -z "$SHOWCOMMENTSHORT" ] && [ ! "$COMMENTSHORT" = "User Comments:" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$COMMENTSHORT\"" >> $GLLOG
    fi
    if  [ ! -z "$BOTONELINE" ]; then
     if [ -z "$LOGFORMAT" ]; then
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$ONELINE\"" >> $GLLOG
     else
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TITLE\" \"$GENRECLEAN\" \"$RATINGCLEAN\" \"$COUNTRYCLEAN\" \"$LANGUAGECLEAN\" \"$CERTCLEAN\" \"$RUNTIMECLEAN\" \"$DIRECTORCLEAN\" \"$BUSINESSSHORT\" \"$PREMIERE\" \"$LIMITED\" \"$TAGLINECLEAN\" \"$PLOTCLEAN\"" >> $GLLOG
     fi
    fi
   fi

   if [ ! -z "$DOTIMDB" ]; then

# Echo stuff to the .imdb file
##############################

    if [ ! -z "$DOTIMDBPROG" ]; then
     $DOTIMDBPROG "\"$DATE\" \"$IMDBLNK\" \"$IMDBLKL\" \"$TITLE\" \"$GENRECLEAN\" \"$RATINGCLEAN\" \"$COUNTRYCLEAN\" \"$LANGUAGECLEAN\" \"$CERTCLEAN\" \"$RUNTIMECLEAN\" \"$DIRECTORCLEAN\" \"$BUSINESSSHORT\" \"$PREMIERE\" \"$LIMITED\" \"$TAGLINECLEAN\" \"$PLOTCLEAN\""
    else
     echo -e "$IMDBHEAD" > $IMDBLNK
     OWNER=`ls -1nl $GLROOT$IMDBLKL | tail -1 | { read junk junk owner group junk; echo $owner:$group; };`
     echo "Title........: $TITLE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     echo "-" >> $IMDBLNK
     echo "IMDb Link....: $IMDBURL" | head -1 >> $IMDBLNK
     if [ ! -z "$DIRECTOR" ]; then
      echo "$DIRECTOR" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$GENRE" ]; then
      echo "$GENRE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$RATING" ]; then
      echo "$RATING" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$TAGLINE" ]; then
      echo "$TAGLINE" | fold -s -w $IMDBWIDTH >> $IMDBLNK
     fi
     echo "-" >> $IMDBLNK
     if [ ! -z "$COUNTRY" ]; then
      echo "$COUNTRY" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$LANGUAGE" ]; then
      echo "$LANGUAGE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$CERT" ]; then
      echo "$CERT" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$PREMIERE" ]; then         
      echo "Premiere Date: $PREMIERE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$LIMITED" ]; then      
      echo "Limited Date.: $LIMITED" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$RUNTIME" ]; then
      echo "$RUNTIME" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
     fi
     if [ ! -z "$CAST" ]; then
      echo "-" >> $IMDBLNK
      echo "Credited Cast:" >> $IMDBLNK
      echo "$CAST" | fold -s -w $IMDBWIDTH >> $IMDBLNK
     fi
     if [ ! -z "$BUSINESS" ]; then
      echo "-" >> $IMDBLNK
      echo "Business Data on Opening Weekend:" >> $IMDBLNK
      echo "$BUSINESS" | fold -s -w $IMDBWIDTH >> $IMDBLNK
     fi
     if [ ! -z "$PLOT" ]; then
      echo "-" >> $IMDBLNK
      echo "$PLOT" | fold -s -w $IMDBWIDTH >> $IMDBLNK
     fi
     if [ ! -z "$SHOWCOMMENT" ] && [ ! -z "`echo $COMMENT | grep "^User Comments:" | grep "Check for other user comments.$"`" ]; then
      echo "---" >> $IMDBLNK
      echo "User Comments:" >> $IMDBLNK
      echo "$COMMENT" | grep "^     " | sed "s/     //g" | fold -s -w $IMDBWIDTH >> $IMDBLNK
     fi
     echo -e "$IMDBTAIL" >> $IMDBLNK
    fi
   fi
  fi

# clean up and make ready for next run.
#######################################

 cat $IMDBLOG | grep -v "$IMDBLINE" > $TMPFILE
 cat $TMPFILE > $IMDBLOG
 echo -n "" > $TMPFILE
 echo -n "" > $IMDBPID
 exit 0
fi
exit 0
